package com.fs.ad.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.ad.domain.AdIqiyiAccount;

/**
 * 爱奇艺广告账号Mapper接口
 * 
 * @author fs
 * @date 2025-03-03
 */
public interface AdIqiyiAccountMapper extends BaseMapper<AdIqiyiAccount>{
    /**
     * 查询爱奇艺广告账号
     * 
     * @param id 爱奇艺广告账号主键
     * @return 爱奇艺广告账号
     */
    AdIqiyiAccount selectAdIqiyiAccountById(Long id);

    /**
     * 查询爱奇艺广告账号列表
     * 
     * @param adIqiyiAccount 爱奇艺广告账号
     * @return 爱奇艺广告账号集合
     */
    List<AdIqiyiAccount> selectAdIqiyiAccountList(AdIqiyiAccount adIqiyiAccount);

    /**
     * 新增爱奇艺广告账号
     * 
     * @param adIqiyiAccount 爱奇艺广告账号
     * @return 结果
     */
    int insertAdIqiyiAccount(AdIqiyiAccount adIqiyiAccount);

    /**
     * 修改爱奇艺广告账号
     * 
     * @param adIqiyiAccount 爱奇艺广告账号
     * @return 结果
     */
    int updateAdIqiyiAccount(AdIqiyiAccount adIqiyiAccount);

    /**
     * 删除爱奇艺广告账号
     * 
     * @param id 爱奇艺广告账号主键
     * @return 结果
     */
    int deleteAdIqiyiAccountById(Long id);

    /**
     * 批量删除爱奇艺广告账号
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteAdIqiyiAccountByIds(Long[] ids);
}
